import csv
import json
import io
import pypandoc
import os


def readme_to_rst():
    parent_path = os.path.dirname(os.getcwd())
    readme_md_path = os.path.join(parent_path, os.path.join("docs", "README.md"))
    readme_rst_path = os.path.join(parent_path, "README.rst")
    pypandoc.convert(readme_md_path, 'rst', outputfile=readme_rst_path)


def csv_to_json(path):
    """
    Convert the csv file into a json file while removing '/uFEFF' unicode character for space

    :param path: path of the csv file
    :return: print the json folder with same name in same directory
    """
    with io.open(path, 'r', encoding='utf8') as f:
        reader = csv.DictReader((x.replace(u"\uFEFF", u"") for x in f))
        rows = list(reader)

    with open(path[:-3]+"json", 'w', encoding='utf8') as f:
        f.write(json.dumps(rows, sort_keys=False, indent=4, separators=(',', ': '), ensure_ascii=False))


def get_demo_data():
    """
    Will return the csv rows into column list:
    label_A label_B
       1      4
       2      5
       3      6

    Will return
    [(label-A, 1, 2, 3), (label-B, 4, 5, 6)]

    Test value
    [('labels', 'January', 'February', 'March', 'April', 'May', 'June', 'July', 'August'),
    ('values', '10', '9', '8', '7', '6', '4', '7', '8'),
    ('colors', '#F7464A', '#46BFBD', '#FDB45C', '#FEDCBA', '#ABCDEF', '#DDDDDD', '#ABCABC', '#BCAFED')]

    :param path:
    :return:
    """
    parent_path = os.path.abspath(os.path.dirname(__file__))
    demo_file_path = os.path.join(parent_path, "demo.csv")

    with io.open(demo_file_path, 'r', encoding='utf8') as f:
        reader = csv.reader((x.replace(u"\uFEFF", u"") for x in f))
        # column_label = list(reader)[0]
        rows = list(reader)[1:]
        print(list(zip(*rows)))

    return zip(*rows)


if __name__ == "__main__":
    # csv_to_json("demo.csv")
    # get_demo_data()
    # readme_to_rst()
    print(os.path.abspath(os.path.dirname(__file__)))
    pass



# -*- coding: utf-8 -*-
"""
Use export FLASK_APP="charpy.factory:create_app()"


"""
from flask import Flask

from charpy.blueprints.simple_page import simple_page


def create_app(debug=False):
    app = Flask(__name__)
    app.debug = debug

    # add your modules
    app.register_blueprint(simple_page)

    return app


if __name__ == "__main__":
    app = create_app( debug=True)
    app.run()


"""
Flask TDD:
https://github.com/mjhea0/flaskr-tdd

"""
import unittest
from charpy import app


class FlaskTest(unittest.TestCase):

    def test_index(self):
        """inital test. ensure flask was set up correctly"""
        tester = app.app.test_client(self)
        response = tester.get('/', content_type='html/text')
        self.assertEqual(response.status_code, 200)

    def test_chart_with_data(self):
        """inital test. ensure flask was set up correctly"""
        tester = app.app.test_client(self)
        response = tester.get('/chart', content_type='html/text')
        self.assertEqual(response.status_code, 200)

    def test_custom_route(self):
        """inital test. ensure flask was set up correctly"""
        tester = app.app.test_client(self)
        response = tester.get('/hello/world/', content_type='html/text')
        self.assertEqual(response.status_code, 200)


if __name__ == "__main__":
    unittest.main()



from setuptools import setup, find_packages

setup(name                  ='charpy',
      version               ='0.2.0',
      description           ='Render chart from data',
      long_description      ='README.rst',
      classifiers           =[
                              'Development Status :: 3 - Alpha',
                              'License :: OSI Approved :: MIT License',
                              'Programming Language :: Python :: 3.6',
                          ],
      keywords              ='flask chart.js web app chart charpy',
      url                   ='http://github.com/sylhare/chartapp',
      author                ='sylhare',
      author_email          ='sylhare@outlook.com',
      license               ='MIT',
      packages              =find_packages(),
      include_package_data  =True,
      install_requires      =['flask>=0.12'],
      zip_safe              =False)
